@@ -25,7 +25,7 @@ import platform
 import subprocess
 import sys
 
-VERSION='0.6.0'
+VERSION='0.7.3'
 PACKAGE='1'
 PLATFORM='win' + ''.join([ c for c in platform.architecture()[0] if c.isdigit() ])
 INSTALLER='diffuse-%s-%s.%s' % (VERSION, PACKAGE, PLATFORM)
@@ -37,7 +37,7 @@ def mkdir(s):
 
 # copies a file to 'dest'
 def copyFile(src, dest, use_text_mode=False,enc=None):
-    print 'copying "%s" to "%s"' % (src, dest)
+    print('copying "%s" to "%s"' % (src, dest))
     if use_text_mode:
         r, w = 'r', 'w'
     else:
@@ -46,14 +46,14 @@ def copyFile(src, dest, use_text_mode=False,enc=None):
     s = f.read()
     f.close()
     if enc is not None:
-        s = codecs.encode(unicode(s, 'utf_8'), enc)
+        s = codecs.encode(str(s, encoding='utf_8'), enc)
     f = open(dest, w)
     f.write(s)
     f.close()
 
 # recursively copies a directory to 'dest'
 def copyDir(src, dest):
-    print 'copying "%s" to "%s"' % (src, dest)
+    print('copying "%s" to "%s"' % (src, dest))
     mkdir(dest)
     for f in os.listdir(src):
         s = os.path.join(src, f)
@@ -125,10 +125,10 @@ copyDir('..\\src\\usr\\share\\icons', 'dist\\share\\icons')
 # translations
 mkdir('dist\\share\\locale')
 locale_dir = os.path.join(gtk_dir, 'share\\locale')
-for s in glob.glob('..\\translations\\*.po'):
+for s in glob.glob('..\\po\\*.po'):
     lang = s[16:-3]
     # Diffuse localisations
-    print 'Compiling %s translation' % (lang, )
+    print('Compiling %s translation' % (lang, ))
     d = 'dist'
     for p in [ 'locale', lang, 'LC_MESSAGES' ]:
         d = os.path.join(d, p)
@@ -190,14 +190,14 @@ for lang in os.listdir(d):
         while True:
             i = s.find('&#', idx)
             if i < 0:
-                a.append(unicode(s[idx:], 'latin_1'))
+                a.append(str(s[idx:], encoding='latin_1'))
                 break
-            a.append(unicode(s[idx:i], 'latin_1'))
+            a.append(str(s[idx:i], encoding='latin_1'))
             i += 2
             j = s.find(';', i)
-            a.append(unichr(int(s[i:j])))
+            a.append(chr(int(s[i:j])))
             idx = j + 1
-        s = u''.join(a)
+        s = ''.join(a)
         s = codecs.encode(s, 'utf-8')
         # clean up translator credit portion
         div = extract_tag(s, '<div class="othercredit">', '</div>')
@@ -227,7 +227,7 @@ copyFile('style.css', 'dist\\style.css')
 # Package everything into a single EXE installer.
 #
 
-# build binary installer 
+# build binary installer
 copyFile(os.path.join(os.environ['ADD_PATH_HOME'], 'add_path.exe'), 'dist\\add_path.exe')
 if os.system('iscc diffuse.iss /F%s' % (INSTALLER, )) != 0:
     raise OSError('Could not run iscc')
@@ -236,4 +236,4 @@ if os.system('iscc diffuse.iss /F%s' % (INSTALLER, )) != 0:
 # Declare success.
 #
 
-print 'Successfully created "%s".' % (INSTALLER, )
+print('Successfully created "%s".' % (INSTALLER, ))
